@@ -1,23 +1,11 @@
 /*
  * This file is part of maemopad
  *
- * Copyright (C) 2005 Nokia Corporation.
+ * Copyright (C) 2005-2008 Nokia Corporation. All rights reserved.
  *
- *
- * This software is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public License
- * as published by the Free Software Foundation; either version 2.1 of
- * the License, or (at your option) any later version.
- *
- * This software is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this software; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301 USA
+ * This maemo code example is licensed under a MIT-style license,
+ * that can be found in the file called "COPYING" in the root
+ * directory.
  *
  */
 
@@ -34,6 +22,8 @@
 #include <locale.h>
 #include <libosso.h>
 
+#define OSSO_SERVICE "com.nokia."PACKAGE
+
 #define _(String) gettext(String)
 
 #include <config.h>
@@ -55,7 +45,7 @@ static AppData *create_data ()
 {
     AppData *result = g_new0( AppData, 1 );
 
-    result->osso = osso_initialize ( PACKAGE, VERSION, TRUE, NULL );
+    result->osso = osso_initialize ( OSSO_SERVICE, VERSION, TRUE, NULL );
     g_assert ( result->osso );
     return result;
 }
