@@ -1,23 +1,11 @@
 /*
  * This file is part of maemopad
  *
- * Copyright (C) 2005 Nokia Corporation.
+ * Copyright (C) 2005-2008 Nokia Corporation. All rights reserved.
  *
- *
- * This software is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public License
- * as published by the Free Software Foundation; either version 2.1 of
- * the License, or (at your option) any later version.
- *
- * This software is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this software; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301 USA
+ * This maemo code example is licensed under a MIT-style license,
+ * that can be found in the file called "COPYING" in the root
+ * directory.
  *
  */
 
@@ -31,7 +19,7 @@
 #include <libgnomevfs/gnome-vfs.h>
 
 /*send via email*/
-#include <ossoemailinterface.h>
+#include <libmodest-dbus-client/libmodest-dbus-client.h>
 /*send via bt */
 #include <conbtdialogs-dbus.h>
 #include <dbus/dbus-glib.h>
@@ -176,24 +164,28 @@ void callback_edit_paste( GtkAction * action, gpointer data )
 /*send via stuff */
 void callback_sendvia_email ( GtkAction * action, gpointer data )
 {
-    osso_return_t ret = OSSO_ERROR;
+    gboolean result = TRUE;
     GSList *list = NULL;
-    gchar *uri = NULL;
     AppUIData *mainview = NULL;
     mainview = ( AppUIData * ) data;
 
+    /* Attach the saved file (and not the one currently on screen). If the file 
+     * has not yet been saved, nothing will be attached */	
 
-    uri = g_strdup(mainview->file_name);
-    g_print("Send %s via email \n", uri);
-
-    list = g_slist_append(list, uri);
-
-    ret = osso_email_files_email(mainview->data->osso, list);
+    if (mainview->file_name) {
+    	list = g_slist_append(list, mainview->file_name);
+        result = libmodest_dbus_client_compose_mail(mainview->data->osso, /*osso_context_t*/           			
+	NULL, /*to*/       
+	NULL, /*cc*/
+	NULL, /*bcc*/
+	NULL, /*body*/
+	NULL, /*subject*/
+	list /*attachments*/);
+    }
 
     g_slist_free(list);
-    g_free(uri);
 
-    if (ret != OSSO_OK) {
+    if (result == FALSE) {
         g_print("Could not send via email\n");
     }
 
